==> RsCMX_Signaling-4.0.120.tar.gz: RsCMX_Signaling-4.0.120/RsCMX_Signaling/Implementations/Configure/Signaling/Nradio/Cell/Cdrx/Uplink/Rtimer.py <==
from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........Internal.Types import DataType
from ........Internal.ArgSingleList import ArgSingleList
from ........Internal.ArgSingle import ArgSingle


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class RtimerCls:
	"""Rtimer commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("rtimer", core, parent)

	def set(self, cell_name: str, timer: int) -> None:
		"""SCPI: [CONFigure]:SIGNaling:NRADio:CELL:CDRX:UL:RTIMer \n
		Snippet: driver.configure.signaling.nradio.cell.cdrx.uplink.rtimer.set(cell_name = '1', timer = 1) \n
		Configures the 'drx-RetransmissionTimerUL'. \n
			:param cell_name: No help available
			:param timer: No help available
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('cell_name', cell_name, DataType.String), ArgSingle('timer', timer, DataType.Integer))
		self._core.io.write(f'CONFigure:SIGNaling:NRADio:CELL:CDRX:UL:RTIMer {param}'.rstrip())

	def get(self, cell_name: str) -> int:
		"""SCPI: [CONFigure]:SIGNaling:NRADio:CELL:CDRX:UL:RTIMer \n
		Snippet: value: int = driver.configure.signaling.nradio.cell.cdrx.uplink.rtimer.get(cell_name = '1') \n
		Configures the 'drx-RetransmissionTimerUL'. \n
			:param cell_name: No help available
			:return: timer: No help available"""
		param = Conversions.value_to_quoted_str(cell_name)
		response = self._core.io.query_str(f'CONFigure:SIGNaling:NRADio:CELL:CDRX:UL:RTIMer? {param}')
		return Conversions.str_to_int(response)

==> RsCMX_Signaling-7.70.0.tar.gz: RsCMX_Signaling-7.70.0/RsCMX_Signaling/Implementations/Configure/Signaling/Nradio/Cell/Cdrx/Uplink/Rtimer.py <==
from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........Internal.Types import DataType
from ........Internal.ArgSingleList import ArgSingleList
from ........Internal.ArgSingle import ArgSingle


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class RtimerCls:
	"""Rtimer commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("rtimer", core, parent)

	def set(self, cell_name: str, timer: int) -> None:
		"""SCPI: [CONFigure]:SIGNaling:NRADio:CELL:CDRX:UL:RTIMer \n
		Snippet: driver.configure.signaling.nradio.cell.cdrx.uplink.rtimer.set(cell_name = 'abc', timer = 1) \n
		Configures the 'drx-RetransmissionTimerUL'. \n
			:param cell_name: No help available
			:param timer: No help available
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('cell_name', cell_name, DataType.String), ArgSingle('timer', timer, DataType.Integer))
		self._core.io.write(f'CONFigure:SIGNaling:NRADio:CELL:CDRX:UL:RTIMer {param}'.rstrip())

	def get(self, cell_name: str) -> int:
		"""SCPI: [CONFigure]:SIGNaling:NRADio:CELL:CDRX:UL:RTIMer \n
		Snippet: value: int = driver.configure.signaling.nradio.cell.cdrx.uplink.rtimer.get(cell_name = 'abc') \n
		Configures the 'drx-RetransmissionTimerUL'. \n
			:param cell_name: No help available
			:return: timer: No help available"""
		param = Conversions.value_to_quoted_str(cell_name)
		response = self._core.io.query_str(f'CONFigure:SIGNaling:NRADio:CELL:CDRX:UL:RTIMer? {param}')
		return Conversions.str_to_int(response)
